@@ -1,10 +1,12 @@
 from django.forms import (Form, ModelForm, BaseModelForm, model_to_dict,
                           fields_for_model, save_instance, ValidationError,
-                          DEFAULT_DATE_INPUT_FORMATS,
-                          DEFAULT_TIME_INPUT_FORMATS,
-                          DEFAULT_DATETIME_INPUT_FORMATS,
                           Media, MediaDefiningClass)
 
+from django.contrib.localflavor.generic.forms import (
+                          DEFAULT_DATE_INPUT_FORMATS,
+                          DEFAULT_DATETIME_INPUT_FORMATS,
+)
+
 # Import SelectDateWidget from extras
 from django.forms.extras import SelectDateWidget
 
