@@ -277,7 +277,7 @@ class SplitDateTimeWidget(MultiWidget):
 
     def decompress(self, value):
         if value:
-            return [value.date(), value.time().replace(microseconds=0)]
+            return [value.date(), value.time().replace(microsecond=0)]
         return [None, None]
 
 
